PermataVa class

Configuration for Permata Virtual Account payment method.

Constructors

PermataVa({required String vaNumber, String? recipientName})
Creates a new instance of PermataVa.

Properties

hashCode int
The hash code for this object.
no setterinherited
recipientName String?
Name of the recipient.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vaNumber String
Virtual Account number.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the configuration to a JSON representation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited