CustomerDetails class
Represents the details of a customer.
Constructors
- CustomerDetails({String? firstName, String? lastName, String? email, String? phone, BillingAddress? billingAddress, BillingAddress? shippingAddress})
- Creates a new instance of CustomerDetails.
Properties
- billingAddress → BillingAddress?
-
The billing address of the customer.
final
- email → String?
-
The email address of the customer.
final
- firstName → String?
-
The first name of the customer.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastName → String?
-
The last name of the customer.
final
- phone → String?
-
The phone number of the customer.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shippingAddress → BillingAddress?
-
The shipping address of the customer.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts the customer details to a JSON representation.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited